@@ -89,7 +89,7 @@ task <- function(formula,data,name=NULL) {
 # show
 setMethod("show","task",
           function(object) {
-            cat('\nTasl Name :: ',object@name)
+            cat('\nTask Name :: ',object@name)
             cat('\nFormula   :: ')
             print(object@formula)
             cat('\n')
@@ -165,21 +165,15 @@ setClass("cvSettings",
          representation(cvReps='numeric',  # nr. of repetitions
                         cvFolds='numeric', # nr. of folds of each rep.
                         cvSeed='numeric',  # seed of the random generator
-                        strat='logical',   # is the sampling stratified?
-                        dataSplits='data.frame') # user supplied data splits
+                        strat='logical')   # is the sampling stratified?
          )
 
 
 # --------------------------------------------------------------
 # constructor function
-cvSettings <- function(r=1,f=10,s=1234,st=F,ds=NULL) {
-  if (is.null(ds))
-    new("cvSettings",cvReps=r,cvFolds=f,cvSeed=s,strat=st,dataSplits=data.frame())
-  else {
-    si <- apply(ds[,3:4],2,max)
-    new("cvSettings",cvReps=si[2],cvFolds=si[1],cvSeed=s,strat=st,dataSplits=ds)
-  }
-}
+cvSettings <- function(r=1,f=10,s=1234,st=F) 
+  new("cvSettings",cvReps=r,cvFolds=f,cvSeed=s,strat=st)
+
 
 
 # --------------------------------------------------------------
@@ -189,15 +183,11 @@ cvSettings <- function(r=1,f=10,s=1234,st=F,ds=NULL) {
 # show
 setMethod("show","cvSettings",
           function(object) {
-            userSplit <- all(dim(object@dataSplits) != 0)
-            cat(ifelse(!userSplit & object@strat,'\n Stratified ','\n'),
-                object@cvReps,'x',object@cvFolds,
-                '- Fold Cross Validation')
-            if (!userSplit)
-              cat(' run with seed = ', object@cvSeed,'\n')
-            else
-              cat('\n   User-supplied data splits\n')
-          })
+           cat(ifelse(object@strat,'\n Stratified ','\n'),
+               object@cvReps,'x',object@cvFolds,
+               '- Fold Cross Validation run with seed = ',
+               object@cvSeed,'\n')
+         })
 
 
 
@@ -311,22 +301,14 @@ setClass("hldSettings",
          representation(hldReps='numeric', # number of repetitions
                         hldSz='numeric',   # the size (0..1) of the holdout
                         hldSeed='numeric', # the random number seed
-                        strat='logical',   # is the sampling stratified?
-                        dataSplits='data.frame') # user supplied data splits
+                        strat='logical')   # is the sampling stratified?
          )
 
 
 # --------------------------------------------------------------
 # constructor function
-hldSettings <- function(r=1,sz=0.3,s=1234,str=F,ds=NULL) {
-  if (is.null(ds)) 
-    new("hldSettings",hldReps=r,hldSz=sz,hldSeed=s,strat=str,dataSplits=data.frame())
-  else {
-    new("hldSettings",hldReps=max(ds[,4]),
-        hldSz=ds[ds$type=='TEST' & ds$fold==1,],
-        hldSeed=s,strat=str,dataSplits=ds)
-  }
-}
+hldSettings <- function(r=1,sz=0.3,s=1234,str=F) 
+  new("hldSettings",hldReps=r,hldSz=sz,hldSeed=s,strat=str)
 
 
 
@@ -337,15 +319,12 @@ hldSettings <- function(r=1,sz=0.3,s=1234,str=F,ds=NULL) {
 # show
 setMethod("show","hldSettings",
           function(object) {
-            userSplit <- all(dim(object@dataSplits) != 0)
-            cat(ifelse(!userSplit & object@strat,'\n Stratified ','\n'),
-                object@hldReps,'x',
-                100*(1-object@hldSz),'%/',100*object@hldSz,'% Holdout')
-            if (!userSplit)
-              cat(' run with seed = ',object@hldSeed,'\n')
-            else
-              cat('\n   User-supplied data splits\n')
-          })
+           cat(ifelse(object@strat,'\n Stratified ','\n'),
+               object@hldReps,'x',
+               100*(1-object@hldSz),'%/',100*object@hldSz,
+               '% Holdout run with seed = ',
+               object@hldSeed,'\n')
+         })
 
 
 # ==============================================================
@@ -562,19 +541,14 @@ summary.loocvRun <- function(object,...) {
 # class def
 setClass("bootSettings",
          representation(bootSeed='numeric',  # seed of the random generator
-                        bootReps='numeric',  # number of repetitions
-                        dataSplits='data.frame') # user supplied data splits
+                        bootReps='numeric') # number of repetitions
          )
 
 
 # --------------------------------------------------------------
 # constructor function
-bootSettings <- function(seed=1234,nreps=50,ds=NULL) {
-  if (is.null(ds))
-    new("bootSettings",bootSeed=seed,bootReps=nreps,dataSplits=data.frame())
-  else
-    new("bootSettings",bootSeed=seed,bootReps=max(ds[,4]),dataSplits=ds)
-}
+bootSettings <- function(seed=1234,nreps=50)
+  new("bootSettings",bootSeed=seed,bootReps=nreps)
 
 
 
@@ -585,10 +559,8 @@ bootSettings <- function(seed=1234,nreps=50,ds=NULL) {
 # show
 setMethod("show","bootSettings",
           function(object) {
-            cat('\n Bootstrap experiment settings\n\t Seed = ',
-                object@bootSeed,'\n\t Nr. repetitions = ',object@bootReps,'\n')
-            if (all(dim(object@dataSplits) != 0))
-              cat('\n   User-supplied data splits\n')
+           cat('\n Bootstrap experiment settings\n\t Seed = ',
+               object@bootSeed,'\n\t Nr. repetitions = ',object@bootReps,'\n')
          })
 
 
@@ -661,20 +633,15 @@ summary.bootRun <- function(object,...) {
 setClass("mcSettings",
          representation(mcReps='numeric',
                         mcTrain='numeric',mcTest='numeric',
-                        mcSeed='numeric',
-                        dataSplits='data.frame')
+                        mcSeed='numeric')
          )
 
 
 # --------------------------------------------------------------
 # constructor function
-mcSettings <- function(r=10,tr=0.25,ts=0.25,s=1234,ds=NULL)
-  if (is.null(ds)) {
-    new("mcSettings",mcReps=r,mcTrain=tr,mcTest=ts,mcSeed=s)
-  } else {
-    new("mcSettings",mcReps=max(ds[,4]),
-        mcTrain=tr,mcTest=ts,mcSeed=s,dataSplits=ds)
-  }
+mcSettings <- function(r=10,tr=0.25,ts=0.25,s=1234)
+  new("mcSettings",mcReps=r,mcTrain=tr,mcTest=ts,mcSeed=s)
+
 
 
 # --------------------------------------------------------------
@@ -684,21 +651,15 @@ mcSettings <- function(r=10,tr=0.25,ts=0.25,s=1234,ds=NULL)
 # show
 setMethod("show","mcSettings",
           function(object) {
-            userSplit <- all(dim(object@dataSplits) != 0)
-            cat('\n',object@mcReps,
-               ' repetitions Monte Carlo Simulation')
-            if (userSplit) {
-              cat(' using user-supplied data splits\n')
-            } else {
-              cat(' using:',
-                  '\n\t seed = ', object@mcSeed,
-                  '\n\t train size = ',object@mcTrain,
-                  ifelse(object@mcTrain<1,'x NROW(DataSet)',' cases'),
-                  '\n\t test size = ',object@mcTest,
-                  ifelse(object@mcTest<1,'x NROW(DataSet)',' cases'),
-                  '\n'
-                  )
-            }
+           cat('\n',object@mcReps,
+               ' repetitions Monte Carlo Simulation using:',
+               '\n\t seed = ', object@mcSeed,
+               '\n\t train size = ',object@mcTrain,
+               ifelse(object@mcTrain<1,'x NROW(DataSet)',' cases'),
+               '\n\t test size = ',object@mcTest,
+               ifelse(object@mcTest<1,'x NROW(DataSet)',' cases'),
+               '\n'
+               )
          })
 
 
